/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.nodes.role;

import javax.annotation.Nonnull;
import org.openide.nodes.Node;
import it.tidalwave.netbeans.nodes.role.NodeDecorator;

/***********************************************************************************************************************
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class CompositeNodeDecorator implements NodeDecorator
  {
    @Nonnull 
    private final NodeDecorator[] nodeDecorators;

    public CompositeNodeDecorator (final @Nonnull NodeDecorator ... nodeDecorators) 
      {
        this.nodeDecorators = nodeDecorators.clone();
      }

    @Override @Nonnull
    public Node decorate (final @Nonnull Node node)
      {
        Node result = node;
        
        for (final NodeDecorator nodeDecorator : nodeDecorators)
          {
            result = nodeDecorator.decorate(result);
          }
        
        return result;
      } 
  }
